@@ -44,6 +44,7 @@ struct Proxy_fixed
   typedef const T1&                                aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -119,6 +120,7 @@ class Proxy< Mat<eT> >
   typedef const Mat<eT>&                           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -164,6 +166,7 @@ class Proxy< Col<eT> >
   typedef const Col<eT>&                           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -209,6 +212,7 @@ class Proxy< Row<eT> >
   typedef const Row<eT>&                           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -243,7 +247,7 @@ class Proxy< Row<eT> >
 
 
 template<typename T1, typename gen_type>
-class Proxy< Gen<T1, gen_type > >
+class Proxy< Gen<T1, gen_type> >
   {
   public:
   
@@ -254,6 +258,7 @@ class Proxy< Gen<T1, gen_type > >
   typedef const Gen<T1, gen_type>&                 aligned_ea_type;
   
   static const bool use_at      = Gen<T1, gen_type>::use_at;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -287,8 +292,100 @@ class Proxy< Gen<T1, gen_type > >
 
 
 
+template<typename T1>
+class Proxy< Gen<T1, gen_randu> >
+  {
+  public:
+  
+  typedef typename T1::elem_type                   elem_type;
+  typedef typename get_pod_type<elem_type>::result pod_type;
+  typedef Mat<elem_type>                           stored_type;
+  typedef const elem_type*                         ea_type;
+  typedef const Mat<elem_type>&                    aligned_ea_type;
+  
+  static const bool use_at      = false;
+  static const bool use_mp      = false;
+  static const bool has_subview = false;
+  static const bool fake_mat    = false;
+  
+  static const bool is_row = Gen<T1, gen_randu>::is_row;
+  static const bool is_col = Gen<T1, gen_randu>::is_col;
+  
+  arma_aligned const Mat<elem_type> Q;
+  
+  inline explicit Proxy(const Gen<T1, gen_randu>& A)
+    : Q(A)
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline uword get_n_rows() const { return (is_row ? 1 : Q.n_rows);                           }
+  arma_inline uword get_n_cols() const { return (is_col ? 1 : Q.n_cols);                           }
+  arma_inline uword get_n_elem() const { return (is_row ? 1 : Q.n_rows) * (is_col ? 1 : Q.n_cols); }
+  
+  arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
+  arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
+  arma_inline elem_type at_alt     (const uword i)                    const { return Q.at_alt(i);    }
+  
+  arma_inline         ea_type         get_ea() const { return Q.memptr(); }
+  arma_inline aligned_ea_type get_aligned_ea() const { return Q;          }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
+  
+  arma_inline bool is_aligned() const { return memory::is_aligned(Q.memptr()); }
+  };
+
+
+
+template<typename T1>
+class Proxy< Gen<T1, gen_randn> >
+  {
+  public:
+  
+  typedef typename T1::elem_type                   elem_type;
+  typedef typename get_pod_type<elem_type>::result pod_type;
+  typedef Mat<elem_type>                           stored_type;
+  typedef const elem_type*                         ea_type;
+  typedef const Mat<elem_type>&                    aligned_ea_type;
+  
+  static const bool use_at      = false;
+  static const bool use_mp      = false;
+  static const bool has_subview = false;
+  static const bool fake_mat    = false;
+  
+  static const bool is_row = Gen<T1, gen_randn>::is_row;
+  static const bool is_col = Gen<T1, gen_randn>::is_col;
+  
+  arma_aligned const Mat<elem_type> Q;
+  
+  inline explicit Proxy(const Gen<T1, gen_randn>& A)
+    : Q(A)
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline uword get_n_rows() const { return (is_row ? 1 : Q.n_rows);                           }
+  arma_inline uword get_n_cols() const { return (is_col ? 1 : Q.n_cols);                           }
+  arma_inline uword get_n_elem() const { return (is_row ? 1 : Q.n_rows) * (is_col ? 1 : Q.n_cols); }
+  
+  arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
+  arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
+  arma_inline elem_type at_alt     (const uword i)                    const { return Q.at_alt(i);    }
+  
+  arma_inline         ea_type         get_ea() const { return Q.memptr(); }
+  arma_inline aligned_ea_type get_aligned_ea() const { return Q;          }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
+  
+  arma_inline bool is_aligned() const { return memory::is_aligned(Q.memptr()); }
+  };
+
+
+
 template<typename T1, typename eop_type>
-class Proxy< eOp<T1, eop_type > >
+class Proxy< eOp<T1, eop_type> >
   {
   public:
   
@@ -299,6 +396,7 @@ class Proxy< eOp<T1, eop_type > >
   typedef const eOp<T1, eop_type>&                 aligned_ea_type;
   
   static const bool use_at      = eOp<T1, eop_type>::use_at;
+  static const bool use_mp      = eOp<T1, eop_type>::use_mp;
   static const bool has_subview = eOp<T1, eop_type>::has_subview;
   static const bool fake_mat    = eOp<T1, eop_type>::fake_mat;
   
@@ -333,7 +431,7 @@ class Proxy< eOp<T1, eop_type > >
 
 
 template<typename T1, typename T2, typename eglue_type>
-class Proxy< eGlue<T1, T2, eglue_type > >
+class Proxy< eGlue<T1, T2, eglue_type> >
   {
   public:
   
@@ -344,6 +442,7 @@ class Proxy< eGlue<T1, T2, eglue_type > >
   typedef const eGlue<T1, T2, eglue_type>&         aligned_ea_type;
   
   static const bool use_at      = eGlue<T1, T2, eglue_type>::use_at;
+  static const bool use_mp      = eGlue<T1, T2, eglue_type>::use_mp;
   static const bool has_subview = eGlue<T1, T2, eglue_type>::has_subview;
   static const bool fake_mat    = eGlue<T1, T2, eglue_type>::fake_mat;
   
@@ -389,6 +488,7 @@ class Proxy< Op<T1, op_type> >
   typedef const Mat<elem_type>&                    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -435,6 +535,7 @@ class Proxy< Glue<T1, T2, glue_type> >
   
   static const bool use_at      = false;
   static const bool has_subview = false;
+  static const bool use_mp      = false;
   static const bool fake_mat    = false;
   
   static const bool is_row = Glue<T1, T2, glue_type>::is_row;
@@ -479,6 +580,7 @@ class Proxy< mtOp<out_eT, T1, op_type> >
   typedef          const Mat<out_eT>&           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -513,7 +615,7 @@ class Proxy< mtOp<out_eT, T1, op_type> >
 
 
 template<typename out_eT, typename T1, typename T2, typename glue_type>
-class Proxy< mtGlue<out_eT, T1, T2, glue_type > >
+class Proxy< mtGlue<out_eT, T1, T2, glue_type> >
   {
   public:
   
@@ -524,6 +626,7 @@ class Proxy< mtGlue<out_eT, T1, T2, glue_type > >
   typedef          const Mat<out_eT>&           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -569,6 +672,7 @@ class Proxy< subview<eT> >
   typedef const subview<eT>&                       aligned_ea_type;
   
   static const bool use_at      = true;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -614,6 +718,7 @@ class Proxy< subview_col<eT> >
   typedef const subview_col<eT>&                   aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -659,6 +764,7 @@ class Proxy< subview_row<eT> >
   typedef const subview_row<eT>&                   aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -704,6 +810,7 @@ class Proxy< subview_elem1<eT,T1> >
   typedef const Proxy< subview_elem1<eT,T1> >&     aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -756,6 +863,7 @@ class Proxy< subview_elem2<eT,T1,T2> >
   typedef const Mat<eT>&                           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -801,6 +909,7 @@ class Proxy< diagview<eT> >
   typedef const diagview<eT>&                      aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -846,6 +955,7 @@ class Proxy< spdiagview<eT> >
   typedef const spdiagview<eT>&                    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -899,6 +1009,7 @@ class Proxy_diagvec_mat< Op<T1, op_diagvec> >
   typedef const diagview<elem_type>&               aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -953,6 +1064,7 @@ class Proxy_diagvec_expr< Op<T1, op_diagvec> >
   typedef const Mat<elem_type>&                    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -1034,6 +1146,7 @@ struct Proxy_xtrans_default< Op<T1, op_htrans> >
   typedef const xtrans_mat<elem_type,true>&        aligned_ea_type;
   
   static const bool use_at      = true;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1073,6 +1186,7 @@ struct Proxy_xtrans_default< Op<T1, op_strans> >
   typedef const xtrans_mat<elem_type,false>&       aligned_ea_type;
   
   static const bool use_at      = true;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1118,6 +1232,7 @@ struct Proxy_xtrans_vector< Op<T1, op_htrans> >
   typedef const Mat<elem_type>&                    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = quasi_unwrap<T1>::has_subview;
   static const bool fake_mat    = true;
   
@@ -1156,6 +1271,7 @@ struct Proxy_xtrans_vector< Op<T1, op_strans> >
   typedef const Mat<elem_type>&                    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = quasi_unwrap<T1>::has_subview;
   static const bool fake_mat    = true;
   
@@ -1222,6 +1338,7 @@ class Proxy< Op<T1, op_htrans> >
   typedef typename Proxy_xtrans::aligned_ea_type aligned_ea_type;
   
   static const bool use_at      = Proxy_xtrans::use_at;
+  static const bool use_mp      = Proxy_xtrans::use_mp;
   static const bool has_subview = Proxy_xtrans::has_subview;
   static const bool fake_mat    = Proxy_xtrans::fake_mat;
   
@@ -1282,6 +1399,7 @@ class Proxy< Op<T1, op_strans> >
   typedef typename Proxy_xtrans::aligned_ea_type aligned_ea_type;
   
   static const bool use_at      = Proxy_xtrans::use_at;
+  static const bool use_mp      = Proxy_xtrans::use_mp;
   static const bool has_subview = Proxy_xtrans::has_subview;
   static const bool fake_mat    = Proxy_xtrans::fake_mat;
   
@@ -1325,6 +1443,7 @@ struct Proxy_subview_row_htrans_cx
   typedef const subview_row_htrans<eT>&     aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1355,6 +1474,7 @@ struct Proxy_subview_row_htrans_non_cx
   typedef const subview_row_strans<eT>&     aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1413,6 +1533,7 @@ class Proxy< Op<subview_row<eT>, op_htrans> >
   typedef typename Proxy_sv_row_ht::ea_type     aligned_ea_type;
   
   static const bool use_at      = Proxy_sv_row_ht::use_at;
+  static const bool use_mp      = Proxy_sv_row_ht::use_mp;
   static const bool has_subview = Proxy_sv_row_ht::has_subview;
   static const bool fake_mat    = Proxy_sv_row_ht::fake_mat;
   
@@ -1458,6 +1579,7 @@ class Proxy< Op<subview_row<eT>, op_strans> >
   typedef const subview_row_strans<eT>&     aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1505,6 +1627,7 @@ class Proxy< Op< Row< std::complex<T> >, op_htrans> >
   typedef const xvec_htrans<eT>&    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -1554,6 +1677,7 @@ class Proxy< Op< Col< std::complex<T> >, op_htrans> >
   typedef const xvec_htrans<eT>&    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -1603,6 +1727,7 @@ class Proxy< Op< subview_col< std::complex<T> >, op_htrans> >
   typedef const xvec_htrans<eT>&    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1650,6 +1775,7 @@ class Proxy< Op<T1, op_htrans2> >
   typedef const eOp< Op<T1, op_htrans>, eop_scalar_times>& aligned_ea_type;
   
   static const bool use_at      = eOp< Op<T1, op_htrans>, eop_scalar_times>::use_at;
+  static const bool use_mp      = eOp< Op<T1, op_htrans>, eop_scalar_times>::use_mp;
   static const bool has_subview = eOp< Op<T1, op_htrans>, eop_scalar_times>::has_subview;
   static const bool fake_mat    = eOp< Op<T1, op_htrans>, eop_scalar_times>::fake_mat;
   
@@ -1698,6 +1824,7 @@ class Proxy< subview_row_strans<eT> >
   typedef const subview_row_strans<eT>&            aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1743,6 +1870,7 @@ class Proxy< subview_row_htrans<eT> >
   typedef const subview_row_htrans<eT>&            aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = false;
   
@@ -1788,6 +1916,7 @@ class Proxy< xtrans_mat<eT, do_conj> >
   typedef const Mat<eT>&                           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -1833,6 +1962,7 @@ class Proxy< xvec_htrans<eT> >
   typedef const Mat<eT>&                           aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = false;
   static const bool fake_mat    = false;
   
@@ -1886,6 +2016,7 @@ class Proxy_vectorise_col_mat< Op<T1, op_vectorise_col> >
   typedef const Mat<elem_type>&                    aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = false;
   static const bool has_subview = true;
   static const bool fake_mat    = true;
   
@@ -1941,6 +2072,7 @@ class Proxy_vectorise_col_expr< Op<T1, op_vectorise_col> >
   typedef typename Proxy<T1>::aligned_ea_type      aligned_ea_type;
   
   static const bool use_at      = false;
+  static const bool use_mp      = Proxy<T1>::use_mp;
   static const bool has_subview = Proxy<T1>::has_subview;
   static const bool fake_mat    = Proxy<T1>::fake_mat;
   
